@@ -14,11 +14,11 @@ __all__ = ["Playlist", "Track", "Extension", "Link", "Meta", "URI",
 URI = str
 NS = {'xspf': "http://xspf.org/ns/0/"}
 
-ET.register_namespace('xspf', NS['xspf'])
+ET.register_namespace('', NS['xspf'])
 
 
 def quote(value: str) -> str:
-    return urlparse.quote(value, safe='/:')
+    return value
 
 
 class XMLAble(ABC):
@@ -186,7 +186,7 @@ class Attribution(XMLAble):
         """Create generator of xml representation."""
         if self.location is not None:
             el = ET.Element('location')
-            el.text = str(urlparse.quote(self.location, safe='/:'))
+            el.text = str(quote(self.location))
             yield el
         if self.identifier is not None:
             el = ET.Element('identifier')
@@ -257,8 +257,7 @@ class Track(XMLAble):
         _Builder().build_track(self, locals())
 
     __slots__ = ('location', 'identifier', 'title', 'creator', 'annotation',
-                 'info', 'image', 'album', 'trackNum', 'duration', 'link',
-                 'meta', 'extension')
+                 'info', 'image', 'album', 'link', 'meta', 'extension')
 
     def __repr__(self) -> str:
         """Return representation `repr(self)`."""
@@ -273,6 +272,36 @@ class Track(XMLAble):
             repr += '>'
         return repr
 
+    @property
+    def trackNum(self) -> int:
+        return self.__trackNum
+
+    @trackNum.setter
+    def trackNum(self, value: int) -> None:
+        if value is not None:
+            if value <= 0:
+                raise ValueError("trackNum must be greater than zero.\n"
+                                 "| Expected: {1, 2, ..}\n"
+                                 f"| Got: {value}")
+            self.__trackNum = value
+        else:
+            self.__trackNum = None
+
+    @property
+    def duration(self) -> int:
+        return self.__duration
+
+    @duration.setter
+    def duration(self, value: int) -> None:
+        if value is not None:
+            if value < 0:
+                raise ValueError("duration must be a non negative integer\n"
+                                 "| Expected: {0, 1, 2, ..}\n"
+                                 f"| Got: {value}")
+            self.__duration = value
+        else:
+            self.__duration = None
+
     def to_xml_element(self) -> ET.Element:
         """Create `xml.ElementTree.Element` of the track."""
         return _XML_Builder(self).build_track()
@@ -373,7 +402,6 @@ class Playlist(UserList, XMLAble):
                               encoding="UTF-8",
                               method="xml",
                               short_empty_elements=True,
-                              default_namespace=NS["xspf"],
                               xml_declaration=True)
 
     @classmethod
@@ -441,22 +469,10 @@ class _Builder():
         self.add_simple_parameter('album')
 
     def add_trackNum(self):
-        trackNum = self.parameters['trackNum']
-        if trackNum is not None:
-            if not int(trackNum) > 0:
-                raise ValueError("""trackNum must be greater than zero""")
-            self.entity.trackNum = int(trackNum)
-        else:
-            self.entity.trackNum = None
+        self.add_simple_parameter('trackNum')
 
     def add_duration(self):
-        duration = self.parameters['duration']
-        if duration is not None:
-            if int(duration) < 0:
-                raise ValueError("""duration must be a non negative integer""")
-            self.entity.duration = duration
-        else:
-            self.entity.duration = None
+        self.add_simple_parameter('duration')
 
     def add_link(self):
         self.entity.link = list(self.parameters['link'])
@@ -519,7 +535,7 @@ class _XML_Builder:
         if self.entity.location is not None:
             for loc in self.entity.location:
                 ET.SubElement(self.xml_element, 'location').text = \
-                    str(urlparse.quote(loc, safe='/:'))
+                    str(quote(loc))
 
     def add_identifiers(self):
         if self.entity.identifier is not None:
